@@ -73,7 +73,7 @@ class DcdbClient(AbstractClient):
 
 
     def CancelDcnJob(self, request):
-        """取消DCN同步
+        """本接口（CancelDcnJob）用于取消DCN同步
 
         :param request: Request instance for CancelDcnJob.
         :type request: :class:`tencentcloud.dcdb.v20180411.models.CancelDcnJobRequest`
@@ -257,6 +257,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateOnlineDDLJob(self, request):
+        """创建在线DDL任务
+
+        :param request: Request instance for CreateOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CreateOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateTmpDCDBInstance(self, request):
         """回档TDSQL实例
 
@@ -350,6 +373,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBackupConfigs(self, request):
+        """本接口(DescribeBackupConfigs)用于查询数据库备份配置信息。
+
+        :param request: Request instance for DescribeBackupConfigs.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeBackupConfigsRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeBackupConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackupConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackupConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBackupFiles(self, request):
         """本接口(DescribeBackupFiles)用于查看备份文件列表。
 
@@ -534,6 +580,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDCDBBinlogTime(self, request):
+        """获取实例回档时可选的时间范围
+
+        :param request: Request instance for DescribeDCDBBinlogTime.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeDCDBBinlogTimeRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeDCDBBinlogTimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDCDBBinlogTime", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDCDBBinlogTimeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDCDBInstanceDetail(self, request):
         """本接口（DescribeDCDBInstanceDetail）用于获取TDSQL实例详情
 
@@ -972,31 +1041,6 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeSqlLogs(self, request):
-        """已废弃接口
-
-        本接口（DescribeSqlLogs）用于获取实例SQL日志。
-
-        :param request: Request instance for DescribeSqlLogs.
-        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeSqlLogsRequest`
-        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeSqlLogsResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeSqlLogs", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeSqlLogsResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeUserTasks(self, request):
         """本接口（DescribeUserTasks）用于拉取用户任务列表
 
@@ -1326,6 +1370,31 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyBackupConfigs(self, request):
+        """本接口(ModifyBackupConfigs)用于修改数据库备份配置信息。
+
+        1. 修改数据库超期备份配置，目前按年、按月、按日只支持一种，存在互斥关系，如当前策略按年备份，如果传入按月备份策略将会覆盖当前的按年备份策略，务必注意。
+
+        :param request: Request instance for ModifyBackupConfigs.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.ModifyBackupConfigsRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.ModifyBackupConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyBackupConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyBackupConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDBEncryptAttributes(self, request):
         """本接口(ModifyDBEncryptAttributes)用于修改实例数据加密。
 
